==> fairreckitlib-0.4.2.tar.gz: fairreckitlib-0.4.2/README.md <==
# FairRecKit Lib
[![Pylint](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pylint.yml/badge.svg)](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pylint.yml)
[![PEP257](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pydocstyle.yml/badge.svg)](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pydocstyle.yml)
[![Pytest with Coverage](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pytest-coverage.yml/badge.svg)](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pytest-coverage.yml)
[![Upload to PyPI](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pypi_publish.yml/badge.svg)](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pypi_publish.yml)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/TheMinefreak23/fairreckitlib?label=Release)

FairRecKitLib is a library that functions as a combinatory interface between a set of existing recommender libraries, such as [Lenskit](https://pypi.org/project/lenskit/), [Implicit](https://pypi.org/project/implicit/), and [Surprise](https://pypi.org/project/scikit-surprise/). It was made to accompany the [FairRecKit application](https://github.com/TheMinefreak23/fair-rec-kit-app).

This program has been developed by students from the bachelor Computer Science at
Utrecht University within the Software Project course.  
© Copyright Utrecht University (Department of Information and Computing Sciences)

# Installation Requirements
FairRecKitLib utilizes the scikit-surprise package, which relies on having a suitable C/C++ compiler present on the system to be able to install itself. For this purpose, make sure you have [Cython](https://pypi.org/project/Cython/) installed before attempting to install FairRecKitLib. If your system lacks a compiler, install the 'Desktop development with C++' build tools through the [Visual Studio installer](https://aka.ms/vs/17/release/vs_buildtools.exe).

Meeting these requirements, you can install FairRecKitLib like any PyPI package, using e.g. pip or conda.

**pip:**  
`pip install fairreckitlib`

**conda**  
`conda install fairreckitlib`

==> fairreckitlib-0.5.1.tar.gz: fairreckitlib-0.5.1/README.md <==
# FairRecKit Lib
[![Pylint](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pylint.yml/badge.svg)](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pylint.yml)
[![PEP257](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pydocstyle.yml/badge.svg)](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pydocstyle.yml)
[![Pytest with Coverage](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pytest-coverage.yml/badge.svg)](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pytest-coverage.yml)
[![Upload to PyPI](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pypi-publish.yml/badge.svg)](https://github.com/TheMinefreak23/fairreckitlib/actions/workflows/pypi-publish.yml)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/TheMinefreak23/fairreckitlib?label=Release)

FairRecKitLib is a library that functions as a combinatory interface between a set of existing recommender libraries, such as [Lenskit](https://pypi.org/project/lenskit/), [Implicit](https://pypi.org/project/implicit/), and [Surprise](https://pypi.org/project/scikit-surprise/). It was made to accompany the [FairRecKit application](https://github.com/TheMinefreak23/fair-rec-kit-app).

This program has been developed by students from the bachelor Computer Science at
Utrecht University within the Software Project course.  
© Copyright Utrecht University (Department of Information and Computing Sciences)

# Installation Requirements
FairRecKitLib utilises the scikit-surprise package, which relies on having a suitable C/C++ compiler present on the system to be able to install itself. For this purpose, make sure you have [Cython](https://pypi.org/project/Cython/) installed before attempting to install FairRecKitLib. If your system lacks a compiler, install the 'Desktop development with C++' build tools through the [Visual Studio installer](https://aka.ms/vs/17/release/vs_buildtools.exe).

Meeting these requirements, you can install FairRecKitLib like any PyPI package, using e.g. pip or conda.

**pip:**  
`pip install fairreckitlib`

**conda**  
`conda install fairreckitlib`

# Documentation
Please check out the [FairRecKitLib Wiki](https://github.com/TheMinefreak23/fairreckitlib/wiki) and [FairRecKitLib API](https://theminefreak23.github.io/fairreckitlib/src/fairreckitlib) for instructions and guides on how to utilise the library or add new functionality.
